# ruff: noqa -- DO NOT UPDATE this @generated file

from __future__ import annotations

from typing import Literal, TypedDict

from typing_extensions import NotRequired


class Table1(TypedDict):
    id: str
    """
    Unique identifier for the record
    """
    name: str
    """
    Name of the entity
    """
    status: Literal['active', 'inactive', 'pending']
    """
    Current status of the entity
    """
    value: float
    """
    Numeric value associated with the entity
    """
    itemCount: NotRequired[int]
    """
    Count of items
    """
    isVerified: bool
    """
    Whether the entity has been verified
    """
    createdDate: str
    """
    Date when the entity was created
    """
    description: NotRequired[str]
    """
    Optional description of the entity
    """



# ruff: noqa -- DO NOT UPDATE this @generated file

from __future__ import annotations

from typing import Literal, TypedDict

from typing_extensions import NotRequired


class Table2(TypedDict):
    id: str
    """
    Unique identifier for the record
    """
    table1Id: NotRequired[str]
    """
    Reference to the parent table1 record. If not provided, the record is independent
    """
    title: str
    """
    Title or name of the item
    """
    amount: float
    """
    Monetary or numeric amount
    """
    priority: Literal['low', 'medium', 'high']
    """
    Priority level of the item
    """
    percentage: NotRequired[float]
    """
    Percentage value between 0 and 100
    """
    notes: NotRequired[str]
    """
    Additional notes or comments
    """
    isActive: bool
    """
    Whether the item is currently active
    """



# ruff: noqa -- DO NOT UPDATE this @generated file

from __future__ import annotations

from typing import Literal, Sequence, TypedDict, Union


class Table1Resource(TypedDict):
    name: Literal['table1']
    tableSchema: Literal['https://fairspec.github.io/schemas/0.1.1/table1.json']


class Table2Resource(TypedDict):
    name: Literal['table2']
    tableSchema: Literal['https://fairspec.github.io/schemas/0.1.1/table2.json']


Resource = Union[Table1Resource, Table2Resource]


Dataset = TypedDict(
    'Dataset',
    {
        '$schema': Literal['https://fairspec.github.io/profiles/0.1.1/dataset.json'],
        'resources': Sequence[Resource],
    },
)


class FairspecExtensionProfile(Dataset):
    pass
